# *****************************************************************************
# * Copyright by ams OSRAM AG                                                 *
# * All rights are reserved.                                                  *
# *                                                                           *
# * IMPORTANT - PLEASE READ CAREFULLY BEFORE COPYING, INSTALLING OR USING     *
# * THE SOFTWARE.                                                             *
# *                                                                           *
# * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
# * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT         *
# * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS         *
# * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT  *
# * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,     *
# * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT          *
# * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES LOSS OF USE,      *
# * DATA, OR PROFITS OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY      *
# * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT       *
# * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE     *
# * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      *
# *****************************************************************************
"""
Update Linux target binaries.
"""

from pathlib import Path
from subprocess import call

do_reboot = False
do_service_restart = False

zmq_installer = Path("./zeromq/install_zmq_linux_server.py")
zmq_service_name = "tmf8806_zmq_server"
pin_header_driver_path = Path("/sys/class/i2c-adapter/i2c-1/1-0041/")

# Detect Linux driver
if pin_header_driver_path.exists():
    driver_installer = Path("./driver/tmf8806_install_pinheader.sh")
else:
    driver_installer = Path("./driver/tmf8806_install.sh")

if zmq_installer.exists():
    print("Install TMF8806 ZeroMQ server.")
    call(["python3",
          zmq_installer.absolute(),
          zmq_installer.parent.absolute()/"tmf8806_zeromq_server_linux.zip",
          f"--name={zmq_service_name}"])
    call(["systemctl", "daemon-reload"])
    call(["systemctl", "enable", zmq_service_name])
    do_service_restart = True

if driver_installer.exists():
    print("Install TMF8806 Linux driver")
    driver_installer.chmod(0o777)
    call(f"./{driver_installer.name}", cwd=driver_installer.parent.absolute())
    call("sync")
    do_reboot = True


if do_reboot:
    print("Reboot")
    call("reboot")

elif do_service_restart:
    call(["systemctl", "restart", zmq_service_name])
